@@ -1,6 +1,6 @@
 
 stopifnot(require(RDieHarder, quiet=TRUE))
 
-dh <- dieharder("rand", "runs", seed=12345)
+dh <- dieharder("rand", "diehard_runs", seed=12345)
 
 print(summary(dh))
